@@ -1,6 +1,6 @@
-static char rcsid[] = "$Id: main.cc,v 1.106 2001/06/04 17:54:16 bmah Exp $";
+static char rcsid[] = "$Id: main.cc 1082 2005-02-12 19:40:04Z bmah $";
 //
-// $Id: main.cc,v 1.106 2001/06/04 17:54:16 bmah Exp $
+// $Id: main.cc 1082 2005-02-12 19:40:04Z bmah $
 //
 // main.cc
 // Bruce A. Mah <bmah@acm.org>
@@ -1401,22 +1401,20 @@ endreps:
 		    else {
 			fprintf(stdout, "(%s)\n", pct->GetName(checkAddress[m]));
 		    }
+#ifdef HAVE_SNMP
+		    if (!ReadFilename && SnmpFlag) {
+			GetIfInfo *gifp;
+			gifp = new GetIfInfo(checkAddress[m], pct);
+			PrintIfInfo(gifp);
+			delete gifp;
+		    }
+#endif /* HAVE_SNMP */
 		}
 	    }
 	    else {
-		fprintf(stderr, "Received probe responses but no addresses recorded\n");
-		abort();
+		fprintf(stdout, "%2d: no probe responses\n", i+StartHop);
+		lastHopFlag = false;
 	    }
-
-#ifdef HAVE_SNMP
-	    if (!ReadFilename && SnmpFlag) {
-		GetIfInfo *gifp;
-		gifp = new GetIfInfo(checkAddress, pct);
-		PrintIfInfo(gifp);
-		delete gifp;
-	    }
-#endif /* HAVE_SNMP */
-
 	}
 
 	// Update inter-hop state
