@@ -1,5 +1,5 @@
 // -*- c++ -*-
-// $Id: pc.h,v 1.32 2001/06/07 15:01:41 bmah Exp $
+// $Id: pc.h 1082 2005-02-12 19:40:04Z bmah $
 //
 // pc.h
 // Bruce A. Mah <bmah@acm.org>
@@ -75,37 +75,12 @@ typedef enum {
 // the more widely-used sockets API standards here.
 #ifdef linux
 
-// We already did a check for <features.h> at configure time, in which
-// case we tried to turn on _BSD_SOURCE.  Pull in <features.h>
-// again just in case no one did it so far.  #include files should
-// be idempotent anyways.
-#include <features.h>
-
-// Pre-glibc2 systems may not have the bsd-backward-compatability
-// macro.
-#if !(defined(__GLIBC__) && (__GLIBC__ >= 2))
-
-// IP
-#define ip_sum			ip_csum
-
-// ICMP
-#define icmp			icmphdr
-#define	icmp_type		type
-#define icmp_code		code
-
-#define ICMP_UNREACH		ICMP_DEST_UNREACH
-#define ICMP_UNREACH_PORT	ICMP_PORT_UNREACH
-#define ICMP_UNREACH_FILTER_PROHIB	ICMP_PKT_FILTERED
-
-#define ICMP_TIMXCEED		ICMP_TIME_EXCEEDED
-
 // UDP
 #define	uh_sport		source
 #define	uh_dport		dest
 #define	uh_ulen			len
 #define uh_sum			check
 
-#endif /* glibc */
 #endif /* linux */
 
 // Make sure we have a definition for the maximum IP packet size.
@@ -119,6 +94,11 @@ typedef enum {
 #define IPV6_MAXPACKET		65535
 #endif /* IPV6_MAXPACKET */
 
+// Some systems might not have MAXTTL
+#ifndef MAXTTL
+#define MAXTTL			255
+#endif /* MAXTTL */
+
 // Some systems might not have IPV6_MAXHLIM.  This is intended for Linux
 // systems (observed on RH 7.1), but might be applicable elsewhere.
 // NRL-derived IPv6 systems have this constant defined below.
